[![PyPI](https://img.shields.io/pypi/v/beam-bc365.svg)](https://pypi.org/project/beam-bc365/) [![PyPI - Downloads](https://img.shields.io/pypi/dm/beam-bc365.svg)](https://pypi.org/project/beam-bc365/)

# About

A collection of transforms for Microsoft Business Central 265 for the [Apache beam](https://beam.apache.org/) python SDK.

# Installation

- Using pip

```bash
pip install beam-bc3675
```

- From source

```bash
git clone git@github.com:Spazzy757/beam-bc365.git
cd beam-bc365
pip install .
```
